#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_MIN_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_MIN_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/scalar/min.hpp>

#endif
